Changelog
=========

1.0.2 (2016-09-07)
------------------

- Introduced CI on Windows via appveyor and a number of issues specific
  to Python 2.7 on Windows have been fixed here and in both upstream.

1.0.0 (2016-09-04)
------------------

- Initial implementation that enables the availability of bower-1.7.x
  into the calmjs framework through the framework itself.
- Allow the declaration of bower.json through setuptools (as bower_json
  setup field)
- Enable ``calmjs bower`` option in the same manner as ``calmjs npm``.
